package main

import (
	"fmt"
	"gitea.zjmud.xyz/phyer/blingo/cache"
	"gitea.zjmud.xyz/phyer/blingo/collector"
	"gitea.zjmud.xyz/phyer/blingo/config"
	"gitea.zjmud.xyz/phyer/blingo/feature_processor"
	"gitea.zjmud.xyz/phyer/blingo/scheduler"
	"gitea.zjmud.xyz/phyer/blingo/storage"
	"log"
)

func main() {
	// 1. 加载配置
	cfg, err := config.LoadConfig("config/config.yaml")
	if err != nil {
		log.Fatalf("Error loading config: %v", err)
	}
	fmt.Println("Configuration loaded successfully.")

	// 2. 数据采集
	data, err := collector.CollectData(cfg)
	if err != nil {
		log.Fatalf("Error collecting data: %v", err)
	}
	fmt.Println("Data collected successfully.")

	// 3. 特征处理
	processedData, err := feature_processor.ProcessFeatures(data)
	if err != nil {
		log.Fatalf("Error processing features: %v", err)
	}
	fmt.Println("Features processed successfully.")

	// 4. 缓存处理
	err = cache.CacheData(processedData)
	if err != nil {
		log.Fatalf("Error caching data: %v", err)
	}
	fmt.Println("Data cached successfully.")

	// 5. 存储数据
	err = storage.StoreData(processedData)
	if err != nil {
		log.Fatalf("Error storing data: %v", err)
	}
	fmt.Println("Data stored successfully.")

	// 6. 调度执行
	scheduler.ScheduleTasks(cfg)
	fmt.Println("Tasks scheduled successfully.")
}
